function logValues = logScale(linValues)
%% logScale change data in linear scale to logarithmic scale.
% It is assumed that input data is voltage or current, because the computation
% is proceed as 20*log10(x).
%
%  INPUTS:
%   linValues: real data in linear scale, double [n1 x n2 x ... x ni]
%
%  OUTPUTS:
%   logValues: data in logarithmic scale, double [n1 x n2 x ... x ni]
%
% © 2020, Viktor Adler, CTU in Prague, adlervik@fel.cvut.cz

linValues(isinf(linValues)) = nan; % omit infinite values
% get range of values
maxVal = max(linValues(:));
minVal = min(linValues(:));
valRange = maxVal - minVal;
% set minimal value to zero
linValues = linValues - minVal;
% if the range is zero (input data is constant) set values to one
if valRange == 0
   linValues = linValues + 1;
else % make range of data into range [0, 1]
   linValues = linValues/valRange;
end
% compute dB from data
logValues = 20*log10(linValues);
% set maximal value in dB range as 0
maxVal = max(logValues(:));
logValues = logValues - maxVal;
end